import { Document, Operation, Project, ProjectStatus } from '@agiliza/api/domain/project'
import {
  DocumentoApiModel,
  ProjetoClienteApiModel,
  ProjetoOperacaoApiModel,
  ProjetoSituacaoApiModel,
  ProjetoSituacaoCompletoApiModel
} from '@microcredito/client'

import { ScheduleAdapter } from './schedule'
import { DomainAdapter } from './shared'

export class ProjectMapper implements DomainAdapter<ProjetoClienteApiModel, Project> {
  private statusAdapter: ProjectStatusAdapter
  private scheduleAdapter: ScheduleAdapter
  private documentAdapter: ProjectDocumentMapper
  // private userCustomerAdapter: UserCustomerMapper
  constructor() {
    this.scheduleAdapter = new ScheduleAdapter()
    this.statusAdapter = new ProjectStatusAdapter()
    this.documentAdapter = new ProjectDocumentMapper()
    // this.userCustomerAdapter = new UserCustomerMapper()
  }
  public mapApiModelToDomain = (apimodel: ProjetoClienteApiModel) => {
    const result: Project = {
      // customer: this.userCustomerAdapter.mapApiModelToDomain(apimodel.cliente),
      processNumber: apimodel.numeroProcesso,
      events: apimodel.eventos ?? [],
      id: apimodel.id,
      status: this.statusAdapter.mapApiModelToDomain(apimodel.situacao),
      schedules: apimodel?.agendamentos?.map(this.scheduleAdapter.mapApiModelToDomain),
      documents: apimodel.documentos.map(this.documentAdapter.mapApiModelToDomain),
    }
    return result
  }
}

// TODO: mudar spec para corrigir status de Visita e Projeto
export class ProjectStatusAdapter implements DomainAdapter<ProjetoSituacaoCompletoApiModel, ProjectStatus> {
  public mapOperacaoToDomain = (oprt: ProjetoOperacaoApiModel): Operation => ({
    id: oprt.codigo,
    description: oprt.descricao,
    descriptionTransition: oprt.descricaoTransicao,
    permission: oprt.permissao === 'cliente' ? 'customer' : 'broker',
  })

  public mapApiModelToDomain = (apimodel: ProjetoSituacaoCompletoApiModel) => {
    const result: ProjectStatus = {
      id: apimodel.codigo,
      description: apimodel.descricao,
      operations: apimodel.operacoes?.map(this.mapOperacaoToDomain),
    }
    return result
  }
}

export class ProjectDocumentMapper implements DomainAdapter<DocumentoApiModel, Document> {
  public mapTipoDocumentoApiToDomain = (tipo: DocumentoApiModel['tipoDocumento']): Document['type'] => ({
    id: tipo.codigo,
    description: tipo.descricao,
  })
  public mapApiModelToDomain = (apimodel: DocumentoApiModel): Document => ({
    id: apimodel.id,
    url: apimodel.imagem,
    type: this.mapTipoDocumentoApiToDomain(apimodel.tipoDocumento),
    extraInformations: apimodel.informacoesComplementares || '',
  })
}

export class ProjectContextStatusMapper implements DomainAdapter<ProjetoSituacaoApiModel, ProjectStatus> {
  public mapApiModelToDomain = (situacao: ProjetoSituacaoApiModel): ProjectStatus => ({
    id: situacao.codigo,
    description: situacao.descricao,
  })
}
