import { UserClient, UserCustomer } from '@agiliza/api/domain'
import { AgendamentoDadosClienteApiModel, UsuarioClienteApiModel } from '@microcredito/client'

import { DomainAdapter } from './shared'

export class UserCustomerMapper implements DomainAdapter<UsuarioClienteApiModel, UserCustomer | undefined> {
  public mapApiModelToDomain = (apimodel?: UsuarioClienteApiModel): UserCustomer | undefined => {
    const result: UserCustomer | undefined = apimodel
      ? {
          cpfcnpj: apimodel.cpfcnpj,
          name: apimodel.nome,
          phone: apimodel.celular,
          ownerCPF: apimodel.cpfResponsavel,
          ownerName: apimodel.nomeResponsavel,
          address: apimodel.endereco
            ? {
                additionalInfo: apimodel.endereco.complemento,
                cep: apimodel.endereco.cep,
                city: apimodel.endereco.municipio,
                state: apimodel.endereco.estado,
                district: apimodel.endereco.bairro,
                number: apimodel.endereco.numero,
                street: apimodel.endereco.logradouro,
                id: apimodel.endereco.id,
              }
            : undefined,
          email: apimodel.email,
        }
      : undefined
    return result
  }
}

export class UserClientMapper implements DomainAdapter<AgendamentoDadosClienteApiModel, UserClient> {
  public mapApiModelToDomain = (apimodel: AgendamentoDadosClienteApiModel): UserClient => {
    const result: UserClient = {
      cpfcnpj: apimodel.cpfcnpj,
      name: apimodel.nome,
    }
    return result
  }
}
