import { GetProjects } from '@agiliza/api/domain'
import { ClienteApi, Configuration } from '@microcredito/client'

import { ErrorMappers, ProjectMappers } from '../mappers'
import { API_URL, mapUserAgentToString, SESSION_KEY, UserAgent } from './shared'

export interface ProjectRepository {
  getProjects(input: GetProjects['Input']): Promise<GetProjects['Output']>
}

export class ProjectRepositoryImpl implements ProjectRepository {
  private api: ClienteApi
  private errorAdapter: ErrorMappers.ResponseErrorAdapter
  private projectMapper: ProjectMappers.ProjectMapper

  constructor(userAgent: string, accessToken: string) {
    this.errorAdapter = new ErrorMappers.ResponseErrorAdapter()
    this.projectMapper = new ProjectMappers.ProjectMapper()

    this.api = new ClienteApi(
      new Configuration({
        basePath: API_URL,
        accessToken,
        headers: {
          'User-Agent': userAgent,
        },
      })
    )
  }

  public getProjects = async (input: GetProjects['Input']): Promise<GetProjects['Output']> => {
    try {
      const projetos = await this.api.obterAcompanhamentos()
      return projetos.map(this.projectMapper.mapApiModelToDomain)
    } catch (e) {
      const result = await this.errorAdapter.mapApiModelToDomain(e)
      throw result
    }
  }
}

export class ProjectRepositoryImplFactory {
  static create(userAgent: UserAgent) {
    const accessToken = localStorage.getItem(SESSION_KEY) || ''
    const repository = new ProjectRepositoryImpl(mapUserAgentToString(userAgent), accessToken)
    return repository
  }
}
