import React from 'react'

import { Button, LinearProgress } from '@mui/material'
import { ButtonProps } from '@mui/material/Button'

import { styles } from './styles'

type ExtendedTypes = Pick<ButtonProps, 'disabled' | 'onClick' | 'type' | 'children' | 'sx' | 'color' | 'size' | 'variant'>

interface Props extends ExtendedTypes {
  fetching?: boolean
}

const ButtonWithProgress = (props: Props) => {
  const { sx, fetching, disabled, onClick, type, children, color = 'primary', size, variant = 'contained' } = props
  return (
    <Button sx={sx} disabled={disabled || fetching} onClick={onClick} variant={variant} color={color} type={type} size={size}>
      {fetching && <LinearProgress sx={styles.progress} />}
      {children}
    </Button>
  )
}

export default ButtonWithProgress
