import React, { useState } from 'react'

import Visibility from '@mui/icons-material/Visibility'
import VisibilityOff from '@mui/icons-material/VisibilityOff'
import InputAdornment from '@mui/material/InputAdornment'
import TextField, { TextFieldProps } from '@mui/material/TextField'

import styles from './styles'

type BaseProps = Pick<TextFieldProps, 'value' | 'onChange' | 'required' | 'label' | 'type' | 'sx' | 'InputProps' | 'autoFocus' | 'inputProps'>

interface Props extends BaseProps {}

const TextFieldWithIcon = (props: Props) => {
  const [isPasswordVisible, setIsPasswordVisible] = useState(false)
  const { onChange, required, value, label, type, sx, InputProps, autoFocus } = props
  return (
    <TextField
      autoFocus={autoFocus}
      required={required}
      value={value}
      onChange={onChange}
      label={label}
      sx={sx}
      variant="outlined"
      type={type === 'password' ? (isPasswordVisible ? undefined : type) : type}
      InputProps={
        InputProps || {
          startAdornment:
            type === 'password' ? (
              <InputAdornment position="start" onClick={() => setIsPasswordVisible(!isPasswordVisible)} sx={styles.inputAdorment}>
                {isPasswordVisible ? <Visibility /> : <VisibilityOff />}
              </InputAdornment>
            ) : null,
        }
      }
    />
  )
}

export default TextFieldWithIcon
