import deepmerge from 'deepmerge'
import React, { useState } from 'react'

import { createSxStyles } from '@agiliza/theme'
import { Box, Collapse, CollapseProps, Fade } from '@mui/material'
import MuiAppBar, { AppBarProps as MuiAppBarProps } from '@mui/material/AppBar'
import { Theme, useTheme } from '@mui/material/styles'

import { Toolbar, ToolbarProps } from './Toolbar'

const useStyles = (theme: Theme) =>
  createSxStyles({
    appBar: {
      // position: 'fixed',
      ...theme.mixins.toolbar,
      background: `linear-gradient(60deg, ${theme.palette.primary.main}, ${theme.palette.primary.light})`,
    },
    content: {
      ...theme.mixins.toolbar,
      display: 'flex',
      alignItems: 'center',
      width: '100%',
    },
  })

type BaseType = Omit<ToolbarProps, 'classes' | 'nav'>

export interface AppBarProps extends BaseType {
  position?: MuiAppBarProps['position']
  children?: React.ReactNode
  onNavClick?(event: React.MouseEvent<HTMLButtonElement, MouseEvent>): void
  style?: MuiAppBarProps['style']
}

const AppBar = ({ sx, position = 'static', actions, title, children, onNavClick, style }: AppBarProps) => {
  const [fadeIn, setFadeIn] = useState(false)
  const styles = useStyles(useTheme())

  const onCollapse: CollapseProps['onEntered'] = (el, isAppearing) => {
    setFadeIn(isAppearing)
  }

  // const nav = onNavClick ? (
  //   <IconButton color="inherit" onClick={onNavClick}>
  //     <DrawerIcon />
  //   </IconButton>
  // ) : null
  return (
    <>
      <MuiAppBar sx={deepmerge(styles.appBar, sx || {})} position={position} style={style}>
        <Toolbar title={title} actions={actions} /*nav={nav}*/ />
        {children && (
          <Collapse appear enter in onEntered={onCollapse} timeout={400}>
            <div>
              <Fade in={fadeIn} enter timeout={600}>
                <Box sx={styles.content}>{children}</Box>
              </Fade>
            </div>
          </Collapse>
        )}
      </MuiAppBar>
    </>
  )
}

export default AppBar
