import deepmerge from 'deepmerge'
import React from 'react'
import { RouteComponentProps } from 'react-router'

import logo from '@agiliza/public/images/logo.svg'
import { actions as loginActions } from '@agiliza/redux/ui/login'
import { ListItemProps } from '@mui/material'
import Divider from '@mui/material/Divider'
import MUIDrawer from '@mui/material/Drawer'
import { useTheme } from '@mui/material/styles'

import { useStyles } from './styles'

type ExtendedTypes = RouteComponentProps

interface DrawerItemsProps extends ExtendedTypes {
  sx: ListItemProps['sx']
  toggleDrawer: () => void
  logout: Props['logout']
}

type BaseProps = RouteComponentProps

export interface Props extends BaseProps {
  drawerOpen: boolean
  toggleDrawer: () => void
  logout: typeof loginActions.logout
  Items?: React.ComponentType<DrawerItemsProps>
}

const Drawer = (props: Props) => {
  const { drawerOpen, toggleDrawer, Items, logout, ...routeProps } = props
  const styles = useStyles(useTheme())

  return (
    <MUIDrawer
      variant="temporary"
      open={drawerOpen}
      sx={deepmerge(styles.drawer, drawerOpen ? styles.drawerOpen : styles.drawerClose)}
      // classes={{
      //   paper: cn(classes.drawer, {
      //     [classes.drawerOpen]: drawerOpen,
      //     [classes.drawerClose]: !drawerOpen,
      //   }),
      // }}
      PaperProps={{
        sx: deepmerge(styles.drawer, drawerOpen ? styles.drawerOpen : styles.drawerClose),
      }}
      onBackdropClick={() => toggleDrawer()}
    >
      <div style={styles.header}>
        <img src={logo} style={styles.headerLogo} alt="Camedics Logo" />
      </div>
      <Divider />
      {Items ? <Items logout={logout} sx={styles.listItem} toggleDrawer={toggleDrawer} {...routeProps} /> : null}
      {/* <DrawerItems listItemClassName={classes.listItem} toggleDrawer={toggleDrawer} {...routerProps} /> */}
      {/* <div className={classes.grow} /> */}
      {/* <Divider />       */}
      {/* <div className={cn(classes.collapseContainer)} onClick={() => toggleDrawer()}>
        <Typography className={classes.iconLabel} variant="h5">
          <DoubleArrowIcon fontSize="large" className={cn({ [style.arrowIconOpened]: drawerOpen })} />
          {drawerOpen ? 'Colapsar' : null}
        </Typography>
      </div> */}
    </MUIDrawer>
  )
}

export default Drawer
