import React, { useEffect, useState } from 'react'
import { connect } from 'react-redux'
import { bindActionCreators, Dispatch } from 'redux'

import { StoreState } from '@agiliza/redux'
import { actions as errorActions, selectors, State as ErrorState } from '@agiliza/redux/ui/error'
import Button from '@mui/material/Button'
import Dialog from '@mui/material/Dialog'
import DialogActions from '@mui/material/DialogActions'
import DialogContent from '@mui/material/DialogContent'
import DialogContentText from '@mui/material/DialogContentText'
import DialogTitle from '@mui/material/DialogTitle'

interface Props {
  error: ErrorState['error']
  setError: typeof errorActions.setErrorMessage
}

const ErrorDialog = (props: Props) => {
  const { error, setError } = props
  const [visible, setVisible] = useState(false)

  useEffect(() => {
    if (error) setVisible(true)
  }, [props.error])

  const handleClose = () => {
    setVisible(false)
    setTimeout(() => {
      setError('')
    }, 200)
  }
  return (
    <Dialog open={visible} onClose={handleClose} aria-labelledby="error-dialog" aria-describedby="error-dialog-description">
      <DialogTitle id="error-dialog-title">Erro</DialogTitle>
      <DialogContent>
        <DialogContentText>{error}</DialogContentText>
      </DialogContent>
      <DialogActions>
        <Button onClick={handleClose} color="primary">
          FECHAR
        </Button>
      </DialogActions>
    </Dialog>
  )
}

const mapStateToProps = (state: StoreState) => ({
  error: selectors.getError(state.ui.error),
})

const mapDispatchToProps = (dispatch: Dispatch) =>
  bindActionCreators(
    {
      setError: errorActions.setErrorMessage,
    },
    dispatch
  )

export default connect(mapStateToProps, mapDispatchToProps)(ErrorDialog)
