import React, { useState } from 'react'

import InfoIcon from '@mui/icons-material/InfoRounded'
import Popover from '@mui/material/Popover'
import { useTheme } from '@mui/material/styles'
import Typography from '@mui/material/Typography'

import { useStyles } from './styles'

interface Props {}

interface PopItem {
  key: string
  value?: string | number
  underline?: boolean
}

const PopoverVersion = (props: Props) => {
  const [popItems] = useState<PopItem[]>([])
  const [anchor, setAnchor] = useState<HTMLDivElement | null>(null)

  const styles = useStyles(useTheme())

  // useEffect(() => {
  //   let items: PopItem[] = [{ key: 'Versão', value: VERSION }]
  //   if (service) {
  //     items = items.concat(
  //       { key: 'ISAPI', value: service?.url, underline: true },
  //       { key: 'Serviço', value: service?.server },
  //       { key: 'Porta', value: service?.port },
  //       { key: 'Sistema', value: service?.system }
  //     )
  //   }
  //   setPopItems(items)
  // }, [service])

  const createPopItems = (items: PopItem[]) =>
    items.map((item, i) => (
      <Typography sx={styles.msg} color="textPrimary" key={i} component="span">
        {`${item.key}: `}
        {<span style={{ textDecoration: item.underline ? 'underline' : undefined }}>{item.value || ''}</span>}
      </Typography>
    ))

  return (
    <div style={styles.root}>
      <div onClick={(evt) => setAnchor(evt.currentTarget)}>
        <InfoIcon sx={styles.infoBtn} color="primary" />
      </div>
      <Popover
        id="version-popover"
        open={!!anchor}
        anchorEl={anchor}
        onClose={() => setAnchor(null)}
        anchorOrigin={{
          vertical: 'top',
          horizontal: 'left',
        }}
        transformOrigin={{
          vertical: 'bottom',
          horizontal: 'right',
        }}
      >
        <div style={styles.popoverContent}>{createPopItems(popItems)}</div>
      </Popover>
    </div>
  )
}
export default PopoverVersion
