import deepmerge from 'deepmerge'
import React from 'react'

import { createSxStyles } from '@agiliza/theme'
import { Theme, useTheme } from '@mui/material/styles'

const useStyles = (theme: Theme) =>
  createSxStyles({
    card: {
      // backgroundColor: '#fafafa',
      height: '100px',
      width: '175px',
      padding: theme.spacing(1),
      border: '1px solid #dfdfdf',
      borderRadius: '10px',
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      justifyContent: 'center',
      // color: theme.palette.grey[500],
      transform: 'scale(1)',
      transition: theme.transitions.create(['color', 'border', 'transform'], {
        duration: theme.transitions.duration.short,
      }),
      '&:hover': {
        transform: 'scale(1.03)',
        color: theme.palette.primary.main,
        borderColor: theme.palette.primary.main,
        cursor: 'pointer',
        border: `1px solid ${theme.palette.primary.main}`,
      },
    },
    cardIcon: {
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
    },
    cardDescription: {
      textAlign: 'center',
    },
  })

export interface DashboardCardProps {
  label: string
  icon: React.ReactNode
  style?: React.CSSProperties
  onClick?(): void
}

function DashboardCard(props: DashboardCardProps) {
  const styles = useStyles(useTheme())
  return (
    <div onClick={props.onClick} style={deepmerge(styles.card, props.style || {})}>
      <div style={styles.cardIcon}>{props.icon}</div>
      <div style={styles.cardDescription}>{props.label}</div>
    </div>
  )
}

export default DashboardCard
