import React from 'react'

import TextFieldWithIcon from '@agiliza/components/atoms/TextFieldWithIcon'
import { AccountCircle } from '@mui/icons-material'
import { InputAdornment, TextFieldProps } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import useStyles from './styles'

interface Props {
  username: string
  password: string
  onChange(type: 'username' | 'password'): TextFieldProps['onChange']
}

const Login = (props: Props) => {
  const styles = useStyles(useTheme())
  const { username, password, onChange } = props

  return (
    <form style={styles.form}>
      <TextFieldWithIcon
        autoFocus
        required
        value={username}
        onChange={onChange('username')}
        label="CPF"
        sx={styles.usernameTxtField}
        inputProps={{ maxLength: 14 }}
        InputProps={{
          startAdornment: (
            <InputAdornment position="start">
              <AccountCircle />
            </InputAdornment>
          ),
        }}
      />
      <TextFieldWithIcon required value={password} onChange={onChange('password')} label="Senha" type="password" />
    </form>
  )
}

export default Login
