import { GetProjects, Project } from '@agiliza/api/domain'
import { types as fetchTypes } from '@agiliza/redux/useCases/project'
import { EntityStore, syncAllIds, syncById } from '@agiliza/utils/method'
import { createSlice, PayloadAction } from '@reduxjs/toolkit'

import { PREFIX } from '../shared'
import { normalizeProjects } from './shared'

export interface Store {
  projects: EntityStore<Project>
}

export const initialState: Store = {
  projects: { byId: {}, allIds: [] },
}

export default createSlice({
  name: `${PREFIX}/project`,
  initialState,
  reducers: {},
  extraReducers: {
    [fetchTypes.getProjects.fulfilled]: (state, action: PayloadAction<GetProjects['Output']>) => {
      const normalized = normalizeProjects(action.payload)

      state.projects.byId = syncById(state.projects, normalized.projects)
      state.projects.allIds = syncAllIds(state.projects, normalized.projects)
    },
  },
})
