import { BusinessData } from '@agiliza/api/domain'
import { createSelector } from '@reduxjs/toolkit'

import { Store } from './slice'

export const getAllIds = (key: keyof Pick<Store, 'productsServices'>) => (state: Store) => {
  return state[key].allIds
}

export const getById = (key: keyof Pick<Store, 'productsServices'>) => (state: Store) => {
  return state[key].byId
}

export const getIdentification = (state: Store) => state.identification
export const getAddress = (state: Store) => state.address
export const getStockSalesCosts = (state: Store) => state.stockSalesCosts

export const getProductsServices = createSelector(getById('productsServices'), getAllIds('productsServices'), (byId, allIds) =>
  allIds.map((id) => byId[id])
)

export const getBusinessData = (state: Store): BusinessData => ({
  identification: getIdentification(state),
  address: getAddress(state),
  stockSalesCosts: getStockSalesCosts(state),
  productsServices: getProductsServices(state),
})
