import {
  AddBDProductService,
  BDProductService,
  BusinessData,
  GetBDProductsServices,
  GetBusinessData,
  UpdateBDProductService
} from '@agiliza/api/domain'
import { types as businessDataTypes } from '@agiliza/redux/useCases/proposalData/businessData'
import { keys, WithEntityStore } from '@agiliza/utils/method'
import { createSlice, PayloadAction } from '@reduxjs/toolkit'

import { PROPOSAL_DATA_PREFIX } from '../shared'
import { normalizeProductsServices } from './shared'

type ExtendedStore = Omit<BusinessData, 'productsServices'> & WithEntityStore<Required<Pick<BusinessData, 'productsServices'>>>

export interface Store extends ExtendedStore {}

export const initialState: Store = {
  identification: undefined,
  address: undefined,
  stockSalesCosts: undefined,
  productsServices: { byId: {}, allIds: [] },
}

const updateProductsServices = (state: Store, pds: BDProductService[]) => {
  const { productsServices } = normalizeProductsServices(pds)
  state.productsServices.byId = productsServices
  state.productsServices.allIds = keys(productsServices)
}

export default createSlice({
  name: `${PROPOSAL_DATA_PREFIX}/businessData`,
  initialState,
  reducers: {},
  extraReducers: {
    [businessDataTypes.getBusinessData.fulfilled]: (state, action: PayloadAction<GetBusinessData['Output']>) => {
      const { payload } = action
      state.identification = payload.identification
      state.address = payload.address
      state.stockSalesCosts = payload.stockSalesCosts

      if (payload.productsServices) updateProductsServices(state, payload.productsServices)
    },
    [businessDataTypes.getProductsServices.fulfilled]: (state, action: PayloadAction<GetBDProductsServices['Output']>) => {
      const { payload } = action
      updateProductsServices(state, payload)
    },
    [businessDataTypes.addProductService.fulfilled]: (state, action: PayloadAction<AddBDProductService['Output']>) => {
      const { payload } = action
      updateProductsServices(state, payload)
    },
    [businessDataTypes.updateProductService.fulfilled]: (state, action: PayloadAction<UpdateBDProductService['Output']>) => {
      const { payload } = action
      updateProductsServices(state, payload)
    },
  },
})
