import { InvolvedPerson } from '@agiliza/api/domain'
import { createSelector } from '@reduxjs/toolkit'

import { Store } from './slice'

export const getAllIds = (key: keyof Pick<Store, 'vehicles' | 'references'>) => (state: Store) => {
  return state[key].allIds
}

export const getById = (key: keyof Pick<Store, 'vehicles' | 'references'>) => (state: Store) => {
  return state[key].byId
}

export const getIdentification = (state: Store) => state.identification
export const getAddress = (state: Store) => state.address
export const getPersonalData = (state: Store) => state.personalData
export const getHome = (state: Store) => state.home
export const getSourceIncome = (state: Store) => state.sourceIncome
export const getSpousePersonalData = (state: Store) => state.spousePersonalData

export const getVehicles = createSelector(getById('vehicles'), getAllIds('vehicles'), (byId, allIds) => allIds.map((id) => byId[id]))
export const getReferences = createSelector(getById('references'), getAllIds('references'), (byId, allIds) => allIds.map((id) => byId[id]))

export const getCustomerData = (state: Store): Omit<InvolvedPerson, 'id'> => ({
  identification: getIdentification(state),
  address: getAddress(state),
  personalData: getPersonalData(state),
  home: getHome(state),
  sourceIncome: getSourceIncome(state),
  spousePersonalData: getSpousePersonalData(state),
  references: getReferences(state),
  vehicles: getVehicles(state),
})
