import {
  AddCDReference,
  AddCDVehicle,
  GetCDReferences,
  GetCDVehicles,
  GetCustomerData,
  InvolvedPerson,
  Reference,
  UpdateCDReference,
  UpdateCDVehicle,
  Vehicle
} from '@agiliza/api/domain'
import { INVOLVED_PERSON_TYPES } from '@agiliza/constants/involvedPeople'
import { types as customerDataTypes } from '@agiliza/redux/useCases/proposalData/customerData'
import { keys, WithEntityStore } from '@agiliza/utils/method'
import { createSlice, PayloadAction } from '@reduxjs/toolkit'

import { PROPOSAL_DATA_PREFIX } from '../shared'
import { normalizeCustomerData } from './shared'

type ExtendedStore = Omit<InvolvedPerson, 'vehicles' | 'references' | 'id'> &
  WithEntityStore<Required<Pick<InvolvedPerson, 'vehicles' | 'references'>>>

export interface Store extends ExtendedStore {}

export const initialState: Store = {
  identification: {
    id: '',
    name: '',
    cpfcnpj: '',
    gender: '',
    type: INVOLVED_PERSON_TYPES['CUSTOMER'],
    account: { agencyNumber: '', number: '', cardPicture: '' },
    dataType: { doesWithdrawal: false, framework: '' },
  },
  address: undefined,
  personalData: undefined,
  home: undefined,
  sourceIncome: undefined,
  spousePersonalData: undefined,
  vehicles: { byId: {}, allIds: [] },
  references: { byId: {}, allIds: [] },
}

const updateVehiclesReferences = (state: Store, pds: Vehicle[] = [], rfs: Reference[] = []) => {
  const { vehicles, references } = normalizeCustomerData(pds, rfs)
  state.vehicles.byId = vehicles
  state.vehicles.allIds = keys(vehicles)

  state.references.byId = references
  state.references.allIds = keys(references)
}

export default createSlice({
  name: `${PROPOSAL_DATA_PREFIX}/customerData`,
  initialState,
  reducers: {},
  extraReducers: {
    [customerDataTypes.getCustomerData.fulfilled]: (state, action: PayloadAction<GetCustomerData['Output']>) => {
      const { payload } = action
      state.identification = payload.identification
      state.address = payload.address
      state.home = payload.home
      state.personalData = payload.personalData
      state.sourceIncome = payload.sourceIncome
      state.spousePersonalData = payload.spousePersonalData

      updateVehiclesReferences(state, payload.vehicles, payload.references)
    },
    [customerDataTypes.getVehicles.fulfilled]: (state, action: PayloadAction<GetCDVehicles['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, payload)
    },
    [customerDataTypes.updateReference.fulfilled]: (state, action: PayloadAction<UpdateCDVehicle['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, payload)
    },
    [customerDataTypes.addReference.fulfilled]: (state, action: PayloadAction<AddCDVehicle['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, payload)
    },
    [customerDataTypes.getReferences.fulfilled]: (state, action: PayloadAction<GetCDReferences['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, [], payload)
    },
    [customerDataTypes.updateReference.fulfilled]: (state, action: PayloadAction<UpdateCDReference['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, [], payload)
    },
    [customerDataTypes.addReference.fulfilled]: (state, action: PayloadAction<AddCDReference['Output']>) => {
      const { payload } = action
      updateVehiclesReferences(state, [], payload)
    },
  },
})
