import { ProjectRepositoryImplFactory } from '@agiliza/api/useCases/project'
import { appPlatform } from '@agiliza/constants/platform'
import { createAsyncReducers, getTypesThunkActions, values } from '@agiliza/utils/method'
import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'

const prefix = 'useCases/project'

export interface State {
  fetching: boolean
}

export const initialState: State = {
  fetching: false,
}

export const actions = {
  getProjects: createAsyncThunk(`${prefix}/getProjects`, async (_, thunkApi) => {
    const useCase = ProjectRepositoryImplFactory.create(appPlatform)
    try {
      return await useCase.getProjects()
    } catch (e) {
      return thunkApi.rejectWithValue(e)
    }
  }),
} as const
export const types = getTypesThunkActions(actions)

export default createSlice({
  name: prefix,
  initialState,
  reducers: {},
  extraReducers: {
    ...values(types).reduce((reducers, type) => ({ ...reducers, ...createAsyncReducers(type) }), {}),
  },
})
