import red from '@mui/material/colors/red'
import { createTheme } from '@mui/material/styles'
import { SxProps } from '@mui/system'

export const defaultToobarHeight = 64

export const theme = createTheme({
  palette: {
    primary: {
      light: '#034da6',
      main: '#0d3366',
    },
    secondary: {
      main: '#23a897',
      contrastText: '#fafafa',
    },
    text: { primary: '#2e2e2e' },
    error: {
      main: red[500],
    },
  },
  mixins: {
    toolbar: {
      minHeight: defaultToobarHeight,
    },
  },
  typography: {
    fontSize: 13,
    fontFamily: "'Rubik', 'Roboto', 'Open Sans', sans-serif",
  },
  components: {
    MuiInputBase: {
      styleOverrides: {
        input: {
          '&:-webkit-autofill': {
            WebkitBoxShadow: '0 0 0 1000px white inset',
          },
        },
      },
    },
    MuiTableCell: {
      styleOverrides: {
        root: {
          fontFamily: 'Heebo',
        },
      },
    },
    MuiListItemText: {
      styleOverrides: {
        primary: {
          fontFamily: 'Heebo',
        },
      },
    },
    MuiDialogContentText: {
      styleOverrides: {
        root: {
          fontFamily: 'Heebo',
        },
      },
    },
    MuiListItemIcon: {
      styleOverrides: {
        root: {
          minWidth: 40,
        },
      },
    },
  },
})

export const createSxStyles = <T extends { [k: string]: SxProps<typeof theme> }>(obj: T) => obj
