import cn from 'classnames'
import React from 'react'

import { browser, SUPPORTED_BROWSERS } from '@agiliza/constants/browser'
import { Link } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import useStyles from './styles'

interface Props {}

const chrome = SUPPORTED_BROWSERS['chrome'].replace(/(>=)/g, '') + '+'
const firefox = SUPPORTED_BROWSERS['firefox'].replace(/(>=)/g, '') + '+'
const edge = SUPPORTED_BROWSERS['windows']['edge'].replace(/(>=)/g, '') + '+'
const safari = SUPPORTED_BROWSERS['macos']['safari'].replace(/(>=)/g, '') + '+'

const BrowserIncompatible = (props: Props) => {
  const styles = useStyles(useTheme())
  return (
    <div style={styles.page}>
      <i className="fas fa-exclamation-circle" style={styles.titleIcon} />
      <h1 style={styles.title}>Navegador não suportado</h1>
      <p style={styles.subTitle}>{`Você está usando o ${browser.getBrowserName()} na versão ${browser.getBrowserVersion()}`}</p>
      <p style={styles.subTitle}>É recomendado utilizar o {process.env.APP_TITLE} em um dos seguintes navegadores:</p>
      <div style={styles.browserList}>
        <Link target="#" sx={styles.anchorBrowser} href="https://www.google.com/chrome/">
          <i className={cn('fab fa-chrome', styles.icon)} />
          Chrome {chrome}
        </Link>
        <Link target="#" sx={styles.anchorBrowser} href="https://www.mozilla.org/en-US/firefox/new/">
          <i className={cn('fab fa-firefox-browser', styles.icon)} />
          Firefox {firefox}
        </Link>
        <Link target="#" sx={styles.anchorBrowser} href="https://www.microsoft.com/en-us/edge">
          <i className={cn('fab fa-edge', styles.icon)}></i>
          Edge {edge}
        </Link>
        <Link target="#" sx={styles.anchorBrowser} href="https://support.apple.com/downloads/safari">
          <i className={cn('fab fa-safari', styles.icon)}></i>
          Safari {safari}
        </Link>
      </div>
    </div>
  )
}

export default BrowserIncompatible
