import React from 'react'

import ItemWithIcon from '@agiliza/components/atoms/ItemWithIcon'
import { AttachMoney as AttachMoneyIcon, ExitToApp } from '@mui/icons-material'
import { ListItemProps } from '@mui/material'
import List from '@mui/material/List'
import { useTheme } from '@mui/material/styles'

import { useStyles } from './styles'

import type { RouteComponentProps } from 'react-router-dom'
import type { Props as DrawerProps } from '@agiliza/components/molecules/Drawer'
interface ListItem {
  label: string
  path: string
  Icon: React.ComponentType
}

export const PATHS = {
  simulation: '/simulacao',
  proposalData: '/dadosProposta',
  proposals: '/propostas',
}

export const drawerListItems: ListItem[] = [
  { label: 'Linhas de Crédito', path: PATHS.simulation, Icon: AttachMoneyIcon },
  // { label: 'Dados da Proposta', path: PATHS.proposalData, Icon: DescriptionIcon },
]

export const mapPathToTitle = (path: string) => {
  return drawerListItems.find((dL) => dL.path === path)?.label || ''
}

type ExtendedTypes = RouteComponentProps

interface Props extends ExtendedTypes {
  sx: ListItemProps['sx']
  toggleDrawer: () => void
  logout: DrawerProps['logout']
}

const isCurrentPath = (history: RouteComponentProps['history'], path: string) => {
  const result = history.location.pathname.replace(/(\/.*?)\/(.*?)$/g, '$1') === path
  return result
}

const DrawerItems = (props: Props) => {
  const styles = useStyles(useTheme())
  const { sx, history, toggleDrawer, logout } = props
  const handleClick = (path: string) => () => {
    history.push(path)
    toggleDrawer()
  }
  const listItemComponent = (label: string, path: string, Icon: React.ComponentType) => (
    <ItemWithIcon key={path} label={label} sx={{ ...sx, ...(isCurrentPath(history, path) ? styles.selected : {}) }} onClick={handleClick(path)}>
      <Icon />
    </ItemWithIcon>
  )

  return (
    <List sx={styles.list}>
      {drawerListItems.map((item) => listItemComponent(item.label, item.path, item.Icon))}
      <ItemWithIcon label="Sair" sx={sx} onClick={() => logout()}>
        <ExitToApp />
      </ItemWithIcon>
    </List>
  )
}

export default DrawerItems
