import React, { lazy, Suspense, useEffect, useState } from 'react'
import { Redirect, Route, RouteComponentProps, Switch, useHistory } from 'react-router'

import AppBar from '@agiliza/components/molecules/AppBar'
import CircularProgress from '@agiliza/components/molecules/CircularProgress'
import { actions as drawerActions } from '@agiliza/redux/ui/drawer'
import { actions as loginActions } from '@agiliza/redux/ui/login'
import { ProposalDataRouteState } from '@agiliza/views/ProposalData/pages/ProposalData'
import { AccountCircleOutlined as PersonIcon, MeetingRoom as LogoutIcon } from '@mui/icons-material'
import { Button, Link, ListItem, ListItemIcon, ListItemText, Menu, Typography } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import connect, { ConnectedProps } from './connect'
import { PATHS } from './DrawerItems'
import useStyles from './styles'

const SimulationCreditLines = lazy(() => import('@agiliza/views/SimulationCreditLines/pages/router'))
const ProposalData = lazy(() => import('@agiliza/views/ProposalData/pages/ProposalData'))
const Projects = lazy(() => import('@agiliza/views/Projects/pages/router'))
// const SecurityProfile = lazy(() => import('@curio/ui/dist/views/SecurityProfile'))

type BaseProps = RouteComponentProps & ConnectedProps

interface Props extends BaseProps {
  toggleDrawer: typeof drawerActions.toggleDrawer
  logout: typeof loginActions.logout
}

const Main = (props: Props) => {
  const { toggleDrawer, fetchMenu, customer } = props
  const styles = useStyles(useTheme())

  const history = useHistory()

  const [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null)

  useEffect(() => {
    fetchMenu()
  }, [])

  const handleProfileClick = (event: React.MouseEvent<HTMLElement>) => {
    setAnchorEl(event.currentTarget)
  }

  const handleClose = () => {
    setAnchorEl(null)
  }

  const handleLogout = () => {
    props.logout({
      onSuccess: () => {
        history.push('/')
        setAnchorEl(null)
      },
    })
  }

  return (
    <div style={styles.pageContainer}>
      <AppBar
        onNavClick={toggleDrawer}
        title={
          <>
            <Link onClick={() => history.push('/')} sx={styles.titleAnchor}>
              <Typography sx={styles.appTitle}>Agiliza</Typography>
            </Link>
            <div style={{ flex: 1 }} />
          </>
        }
        actions={
          <>
            <Button color="inherit" variant="text" onClick={() => history.push(PATHS.proposals)}>
              Retomar proposta
            </Button>
            {customer && <Button onClick={handleProfileClick} key="1" color="inherit" endIcon={<PersonIcon />} />}
          </>
        }
      />
      {/* <Drawer drawerOpen={drawerOpen} toggleDrawer={toggleDrawer} logout={logout} Items={DrawerItems} {...routeProps} /> */}
      <Suspense fallback={<CircularProgress />}>
        <Switch>
          <Route path={PATHS.proposals} render={(rProps) => <Projects {...rProps} />} />
          <Route path={PATHS.simulation} render={(rProps) => <SimulationCreditLines {...rProps} />} />
          <Route
            path={PATHS.proposalData}
            render={(rProps) => {
              const { location } = rProps as RouteComponentProps<any, any, ProposalDataRouteState>
              // if (!location.state) location.state = { subproductId: '0' }
              if (location.state?.proposalId) return <ProposalData {...rProps} />
              else return <Redirect from={PATHS.proposalData} to="/" />
            }}
          />
          <Redirect from="/" to={PATHS.simulation} />
        </Switch>
      </Suspense>
      <Menu id="long-menu" anchorEl={anchorEl} keepMounted open={Boolean(anchorEl)} onClose={handleClose}>
        <ListItem button onClick={handleLogout}>
          <ListItemIcon>
            <LogoutIcon />
          </ListItemIcon>
          <ListItemText>Sair</ListItemText>
        </ListItem>
      </Menu>
    </div>
  )
}

export default connect(Main)
