import React, { useEffect } from 'react'
import { RouteComponentProps } from 'react-router'

import { Project } from '@agiliza/api/domain/project'
import { PATHS } from '@agiliza/views/Main/DrawerItems'
import { Apps as AppsIcon } from '@mui/icons-material'
import {
  Avatar,
  Box,
  CircularProgress,
  List,
  ListItem,
  ListItemAvatar,
  ListItemText,
  ListSubheader
} from '@mui/material'
import { useTheme } from '@mui/material/styles'

import { connected, ConnectedProps } from './connect'
import useStyles from './styles'

type ExtendedProps = ConnectedProps & RouteComponentProps

interface Props extends ExtendedProps {}

const ListProjects = (props: Props) => {
  const { fetching, proposals, history } = props

  const styles = useStyles(useTheme())

  useEffect(() => {
    props.getProjects()
  }, [])

  const handleClickListItem = (proposal: Project) => () => {
    props.setProposalId(proposal.id)
    history.push({ pathname: PATHS.proposalData, state: { proposalId: proposal.id } })
  }

  if (fetching) return <CircularProgress />

  return (
    <Box sx={styles.pageContent}>
      <List
        sx={styles.list}
        subheader={
          <ListSubheader component="div" id="nested-list-subheader">
            Projetos
          </ListSubheader>
        }
      >
        {proposals.map((proposal, i) => (
          <ListItem key={i} button onClick={handleClickListItem(proposal)}>
            <ListItemAvatar>
              <Avatar>
                <AppsIcon />
              </Avatar>
            </ListItemAvatar>
            <ListItemText primary="Número da proposta" secondary={proposal.processNumber} />
          </ListItem>
        ))}
      </List>
    </Box>
  )
}

export default connected(ListProjects)
