import { connect } from 'react-redux'
import { bindActionCreators, Dispatch } from 'redux'

import { Project } from '@agiliza/api/domain/project'
import { StoreState } from '@agiliza/redux'
import * as entProject from '@agiliza/redux/entities/project'
import * as uiSimulation from '@agiliza/redux/ui/simulation'
import * as ucProject from '@agiliza/redux/useCases/project'

export interface ConnectedProps {
  fetching: boolean
  proposals: Project[]
  getProjects: typeof ucProject.actions.getProjects
  setProposalId: typeof uiSimulation.actions.setProposalId
  setPersonId: typeof uiSimulation.actions.setPersonId
}

type StateProps = Pick<ConnectedProps, 'fetching' | 'proposals'>
type DispatchProps = Pick<ConnectedProps, 'getProjects' | 'setProposalId' | 'setPersonId'>

const mapStateToProps = (state: StoreState): StateProps => ({
  fetching: ucProject.selectors.isFetching(state.useCases.project),
  proposals: entProject.selectors.getProjects(state.entities.project),
})

const mapDispatchToProps = (dispatch: Dispatch): DispatchProps =>
  bindActionCreators(
    {
      getProjects: ucProject.actions.getProjects,
      setProposalId: uiSimulation.actions.setProposalId,
      setPersonId: uiSimulation.actions.setPersonId,
    },
    dispatch
  )

export const connected = connect(mapStateToProps, mapDispatchToProps)
