import React, { lazy, Suspense } from 'react'
import { Route, RouteComponentProps, Switch } from 'react-router'

import AuthRoute from '@agiliza/components/atoms/AuthRoute'
import { PATHS } from '@agiliza/views/Main/DrawerItems'
import { Box, CircularProgress } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import useStyles from './shared-styles'

export const PROJECTS_PATHS = {
  login: PATHS.proposals + '/login',
}

const ListProjects = lazy(() => import('./ListProjects'))
const Login = lazy(() => import('@agiliza/views/Login'))

type ExtendedProps = RouteComponentProps

interface Props extends ExtendedProps {}

const ProposalDataRouter = (props: Props) => {
  const styles = useStyles(useTheme())
  return (
    <Box sx={styles.pageContent}>
      <Suspense fallback={<CircularProgress sx={styles.circularProgress} />}>
        <Switch>
          <Route path={PROJECTS_PATHS.login} render={(renderProps) => <Login {...renderProps} redirectTo={PATHS.proposals} />} />
          <AuthRoute path={PATHS.proposals} redirectTo={PROJECTS_PATHS.login} component={ListProjects} />
        </Switch>
      </Suspense>
    </Box>
  )
}

export default ProposalDataRouter
