import React from 'react'

import { extractNumbers } from '@agiliza/utils/extractors'
import { ActionType } from '@agiliza/utils/hooks/state'
import PriceAmountInput, {
  Values
} from '@agiliza/views/ProposalData/components/templates/PriceAmountInput'
import { Box, TextField, TextFieldProps, Typography } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import { BDProductServiceState } from '../state'
import useStyles from './styles'

interface Props {
  state: BDProductServiceState
  actions: ActionType<BDProductServiceState>
}

const Form = (props: Props) => {
  const { state, actions } = props
  const styles = useStyles(useTheme())

  const { description, unit, stock, monthlySales, variableCosts } = state

  const handleChangeText =
    (key: keyof BDProductServiceState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  const handleChangePriceAmount = (keyState: keyof BDProductServiceState) => (value: Partial<Values>) => {
    actions.update({ [keyState]: value })
  }

  return (
    <Box component="form" sx={styles.form}>
      <TextField variant="outlined" label="Descrição do produto / serviço" value={description} onChange={handleChangeText('description')} />
      <TextField variant="outlined" label="Unidade" value={extractNumbers(unit)} onChange={handleChangeText('unit')} type="tel" />
      <Typography sx={styles.label}>Informações de estoque</Typography>
      <PriceAmountInput values={stock} onChange={handleChangePriceAmount('stock')} />
      <Typography sx={styles.label}>Vendas mensais</Typography>
      <PriceAmountInput values={monthlySales} onChange={handleChangePriceAmount('monthlySales')} />
      <Typography sx={styles.label}>Custos variáveis</Typography>
      <PriceAmountInput values={variableCosts} onChange={handleChangePriceAmount('variableCosts')} />
    </Box>
  )
}

export default Form
