import React from 'react'

import { InvolvedPersonType } from '@agiliza/api/domain'
import { Dialog, DialogProps, List, ListItem, ListItemText } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import useStyles from './styles'

type ExtendedProps = Pick<DialogProps, 'open' | 'onClose'>

interface Props extends ExtendedProps {
  onSelectType(type: InvolvedPersonType): () => void
}

const SelectTypeDialog = (props: Props) => {
  const { open, onClose, onSelectType } = props
  const styles = useStyles(useTheme())
  return (
    <Dialog onClose={onClose} aria-labelledby="simple-dialog-title" open={open} PaperProps={{ sx: styles.dialog }}>
      <List>
        <ListItem button onClick={onSelectType('CUSTOMER')}>
          <ListItemText primary="Cliente" sx={styles.listItemText} />
        </ListItem>
        <ListItem button onClick={onSelectType('GUARANTOR')}>
          <ListItemText primary="Avalista" sx={styles.listItemText} />
        </ListItem>
        <ListItem button>
          <ListItemText primary="Sócio" onClick={onSelectType('PARTNER')} sx={styles.listItemText} />
        </ListItem>
      </List>
    </Dialog>
  )
}

export default SelectTypeDialog
