import React, { useState } from 'react'

import {
  AccountBox as AccountBoxIcon,
  CheckBox as CheckBoxIcon,
  ContactMail as ContactMailIcon,
  Forum as ForumIcon,
  Home as HomeIcon,
  List as ListIcon,
  LocalAtm as LocalAtmIcon,
  ZoomOutMap as ZoomOutMapIcon
} from '@mui/icons-material'
import { TabContext, TabList, TabListProps, TabPanel } from '@mui/lab'
import { Tab } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import Identification from './Identification'
import useStyles from './styles'

export const involvedPeopleItems = [
  { label: 'Identificação', icon: <AccountBoxIcon />, component: <Identification /> },
  { label: 'Dados Pessoais', icon: <ListIcon />, component: <div>Dados Pessoais</div> },
  { label: 'Endereço', icon: <ContactMailIcon />, component: <div>Endereço</div> },
  { label: 'Fonte de renda', icon: <LocalAtmIcon />, component: <div>Fonte de renda</div> },
  { label: 'Cônjuge - Ident.', icon: <ForumIcon />, component: <div>Cônjuge - Ident.</div> },
  { label: 'Cônjuge +', icon: <ZoomOutMapIcon />, component: <div>Cônjuge +</div> },
  { label: 'Referências', icon: <CheckBoxIcon />, component: <div>Referências</div> },
  { label: 'Moradia', icon: <HomeIcon />, component: <div>Moradia</div> },
]

interface Props {}

const InvolvedPeople = (props: Props) => {
  const styles = useStyles(useTheme())
  const [tab, setTab] = useState('0')

  const handleChange: TabListProps['onChange'] = (evt, newValue) => {
    setTab(newValue.toString())
  }

  return (
    <div style={styles.contentContainer}>
      <TabContext value={tab}>
        <TabList orientation="vertical" variant="scrollable" value={tab} onChange={handleChange} aria-label="Vertical tabs example" sx={styles.tabs}>
          {involvedPeopleItems.map(({ component, ...tb }, i) => (
            <Tab wrapped key={i} {...tb} value={i.toString()} />
          ))}
        </TabList>
        <div style={styles.content}>
          {involvedPeopleItems.map((tb, i) => (
            <TabPanel key={i} value={i.toString()}>
              {tb.component}
            </TabPanel>
          ))}
        </div>
      </TabContext>
    </div>
  )
}

export default InvolvedPeople
