import React from 'react'

import {
  Box,
  BoxProps,
  Slider,
  SliderProps,
  TextField,
  TextFieldProps,
  Typography
} from '@mui/material'

type ExtendedProps = Record<string, unknown>

interface Props extends ExtendedProps {
  title: string
  valueField: string
  sliderProps?: Pick<SliderProps, 'min' | 'max' | 'marks' | 'step'> & {
    onChange: SliderProps['onChange']
    value: number
  }
  disabled: boolean
  onChangeField: TextFieldProps['onChange']
  onBlurField: TextFieldProps['onBlur']
  suffix?: string
  sx?: BoxProps['sx']
}

const SliderField = (props: Props) => {
  const { sx, title, valueField, disabled, onChangeField, onBlurField, suffix, sliderProps } = props
  const { step = 1 } = sliderProps || { step: 1 }
  return (
    <Box component="div" sx={sx}>
      <Typography gutterBottom>{title}</Typography>
      {sliderProps && <Slider {...sliderProps} disabled={disabled} step={step} />}
      <TextField
        style={{ width: '18%' }}
        disabled={disabled}
        value={valueField}
        onChange={onChangeField}
        onBlur={onBlurField}
        InputProps={{ endAdornment: suffix && <Typography>{suffix}</Typography> }}
        variant="standard"
      />
    </Box>
  )
}

export default SliderField
