import { lightFormat } from 'date-fns'
import React, { useEffect, useState } from 'react'

import { SubProduct } from '@agiliza/api/domain'
import { AMORTIZATIONS } from '@agiliza/constants/amortization'
import { formatCurrency } from '@agiliza/utils/formatters'
import { SelectField } from '@curio/components'
import { Box, Button, Grid } from '@mui/material'
import { useTheme } from '@mui/material/styles'

import { connected, ConnectedProps } from './connect'
import GridLine from './GridLine'
import InstallmentsDialog from './InstallmentsDialog'
import useStyles from './styles'

type ExtendedProps = ConnectedProps

interface Props extends ExtendedProps {
  subproduct?: SubProduct
  onChangeSubproduct: (subprd?: SubProduct) => void
}

const CreditLinesInfo = (props: Props) => {
  const styles = useStyles(useTheme())
  const { subproducts, subproduct, onChangeSubproduct } = props

  // const [selectedSP, setSelectedSP] = useState<SubProduct | undefined>()
  const [open, setOpen] = useState(false)

  useEffect(() => {
    if (subproducts.length === 1) onChangeSubproduct(subproducts[0])
  }, [subproducts])

  return (
    <Box sx={styles.contentContainer}>
      <Box sx={styles.content}>
        <SelectField
          id="subproducts"
          sx={styles.selectField}
          label="Opções de Subproduto"
          items={subproducts.map((sp) => ({ label: sp.description || '', value: sp.id }))}
          value={subproduct?.id || ''}
          onChange={(value) => {
            const subprd = subproducts.find((sp) => sp.id === value)
            onChangeSubproduct(subprd)
          }}
          shrink={false}
        />
        <Grid container sx={styles.gridContainer}>
          <GridLine label="Número de parcelas" value={subproduct?.maxAmountInstallment || ''} />
          {/* <GridLine label="Valor das parcelas" value={formatCurrency(subproduct?.amount.toFixed(2))} /> */}
          <GridLine label="Taxa de juros" value={subproduct?.fee ? `${subproduct?.fee} %` : ''} />
          <GridLine label="Valor total IOF" value={formatCurrency(subproduct?.IOF?.toString() || '')} />
          <GridLine label="Custo efetivo total mensal (CET)" value={`${subproduct?.monthlyCET?.toFixed(2) || ''} %`} />
          <GridLine label="Custo efetivo total anual (CET)" value={`${subproduct?.yearlyCET?.toFixed(2) || ''} %`} />
          <GridLine label="Taxa abertura crédito (TAC)" value={formatCurrency(subproduct?.TAC?.toFixed(2))} />
          <GridLine label="Valor total liberado líquido" value={formatCurrency(subproduct?.totalLiberateLiquidValue?.toFixed(2))} />
          <GridLine label="Valor do empréstimo" value={formatCurrency(subproduct?.loanValue?.toFixed(2))} />
          <GridLine label="Sistema de amortização" value={subproduct?.amortization ? AMORTIZATIONS[subproduct.amortization] : ''} />
          <GridLine label="Quatidade de parcelas da carência" value={subproduct?.graceInstallementAmount?.toString() || ''} />
          <GridLine label="Valor total calculado" value={formatCurrency(subproduct?.totalCalcValue?.toFixed(2) || '')} />
          <GridLine label="Valor total juros" value={formatCurrency(subproduct?.feeTotalValue?.toFixed(2) || '')} />
          <GridLine label="Data base de cálculo" value={subproduct?.baseCalcDate ? lightFormat(subproduct.baseCalcDate, 'dd/MM/yyyy') : ''} />
        </Grid>
        <Button variant="text" onClick={() => setOpen(true)} disabled={!subproduct}>
          Exibir opções de parcelamento
        </Button>
        <InstallmentsDialog open={open} onClose={() => setOpen(false)} installmentOptions={subproduct?.installementOptions} />
      </Box>
    </Box>
  )
}

export default connected(CreditLinesInfo)
